OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Palavra-passe errada",
    "The new password can not be the same as the previous one" : "A nova palavra-passe não pode ser a mesma que a anterior",
    "No user supplied" : "Nenhum utilizador especificado",
    "Authentication error" : "Erro na autenticação",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor, forneça uma palavra-passe de administrador de recuperação; caso contrário, serão perdidos todos os dados do utilizador.",
    "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação de administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "A interface não suporta a alteração da palavra-passe, mas a chave de encriptação foi atualizada com sucesso.",
    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
    "%s password changed successfully" : "Palavra-passe de %s alterada com sucesso",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "A instalar e a atualizar as aplicações através da loja de aplicações ou Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está a usar uma versão %s desatualizada (%s). Por favor, atualize o seu sistema operativo ou algumas funcionalidades como %s não funcionarão corretamente.",
    "A problem occurred, please check your log files (Error: %s)" : "Ocorreu um problema, por favor, verifique os ficheiros de registo (Erro: %s)",
    "Migration Completed" : "Migração Concluída",
    "Group already exists." : "O grupo já existe.",
    "Unable to add group." : "Impossível adicionar o grupo.",
    "Unable to delete group." : "Impossível eliminar grupo.",
    "log-level out of allowed range" : "log-level fora do alcance permitido",
    "Saved" : "Guardado",
    "test email settings" : "testar as definições de correio eletrónico",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Um problema ocorreu ao enviar o email. Por favor verifique as suas definições. (Erro: %s)",
    "Email sent" : "Mensagem de correio eletrónico enviada",
    "You need to set your user email before being able to send test emails." : "Você precisa de configurar o seu e-mail de usuário antes de ser capaz de enviar e-mails de teste",
    "Couldn't change the email address because the user does not exist" : "Não foi possível alterar o endereço de email porque o utlizador não existe",
    "Couldn't change the email address because the token is invalid" : "Não foi possível alterar o endereço de email porque a senha é inválida",
    "Invalid mail address" : "Endereço de e-mail inválido",
    "A user with that name already exists." : "Já existe um utilizador com esse nome.",
    "Unable to create user." : "Impossível criar o utilizador.",
    "Your %s account was created" : "A sua conta %s foi criada",
    "Unable to delete user." : "Impossível eliminar o utilizador.",
    "Forbidden" : "Proibido",
    "Invalid user" : "Utilizador inválido",
    "Unable to change mail address" : "Não é possível alterar o endereço de e-mail",
    "Email has been changed successfully." : "Endereço de email foi alterado com sucesso.",
    "An email has been sent to this address for confirmation" : "Um email foi enviado para este endereço para confirmação",
    "No email was sent because you already sent one recently. Please try again later." : "Nenhum email foi enviado porque já foi enviado um recentemente. Por favor tente mais tarde.",
    "Your full name has been changed." : "O seu nome completo foi alterado.",
    "Unable to change full name" : "Não é possível alterar o nome completo",
    "%s email address confirm" : "Confirmação de endereço de email de %s",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Não foi possível enviar o email de confirmação da mudança de endereço de email. Por favor, contacte o seu administrador.",
    "%s email address changed successfully" : "Endereço de email de %s foi alterado com sucesso",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Não foi possível enviar o email da notificação da mudança de endereço de email. Por favor, contacte o seu administrador.",
    "Unable to enable/disable user." : "Impossível ativar/desativar utilizador.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "Idioma alterado",
    "Invalid request" : "Pedido Inválido",
    "Admins can't remove themself from the admin group" : "Os administradores não se podem remover a eles próprios do grupo 'admin'.",
    "Unknown user" : "Utilizador desconhecido",
    "Couldn't remove app." : "Não foi possível remover a aplicação.",
    "Official" : "Oficial",
    "Approved" : "Aprovado",
    "All" : "Todos",
    "Enabled" : "Ativada",
    "Not enabled" : "Desativada",
    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
    "The app will be downloaded from the app store" : "A aplicação será transferida da loja de aplicações",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "As apps oficiais são desenvolvidas por e na comunidade da ownCloud. Elas oferecem funcionalidade central para a ownCloud e está pronta para uma utilização na produção.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "As aplicações aprovadas são desenvolvidas por developers de confiança e passaram numa verificação de segurança. São mantidas ativamente num repositório de código aberto e quem as mantém considera-as estáveis para uso casual a normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicação não foi verificada por problemas de segurança e é nova ou conhecida por ser instável. Instale-a por sua conta e risco.",
    "Please wait...." : "Por favor, aguarde...",
    "Error while disabling app" : "Erro durante a desativação da aplicação",
    "Disable" : "Desativar",
    "Enable" : "Ativar",
    "Error while enabling app" : "Erro durante a ativação da aplicação",
    "Error: this app cannot be enabled because it makes the server unstable" : "Erro: esta app não pode ser activada porque torna o servidor instável",
    "Error: could not disable broken app" : "Erro: não foi possível desativar a aplicação com problemas",
    "Error while disabling broken app" : "Erro ao desativar a aplicação com problemas",
    "Updating...." : "A atualizar...",
    "Error while updating app" : "Ocorreu um erro enquanto atualizava a app",
    "Updated" : "Atualizada",
    "Uninstalling ...." : "A desinstalar....",
    "Error while uninstalling app" : "Erro durante a desinstalação da aplicação",
    "Uninstall" : "Desinstalar",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada, mas precisa de ser atualizada. Você será redirecionado para a página de atualização em 5 segundos.",
    "App update" : "Atualizar aplicação",
    "Experimental" : "Experimental",
    "No apps found for {query}" : "Não foram encontradas aplicações para {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Você tem certeza que quer adicionar \"{domain}\" como domínio confiável?",
    "Add trusted domain" : "Adicionar domínio confiável ",
    "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que a mesma esteja concluída..",
    "Migration started …" : "Migração iniciada...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor, envie um certificado PEM codificado em ASCII.",
    "Valid until {date}" : "Válida até {date}",
    "Delete" : "Eliminar",
    "Disconnect" : "Desligar",
    "Error while loading browser sessions and device tokens" : "Erro durante o carregamento das sessões do navegador e tokens do dispositivo",
    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
    "Error while deleting the token" : "Erro durante a eliminação do token",
    "Sending..." : "A enviar...",
    "Failed to change the email address." : "Falha ao alterar o endereço de email.",
    "Email changed successfully." : "Email alterado com sucesso.",
    "An error occurred: {message}" : "Ocorreu um erro: {message}",
    "Select a profile picture" : "Selecione uma fotografia de perfil",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "Não é possível eliminar {objNome}",
    "Error creating group: {message}" : "Erro ao criar grupo: {message}",
    "A valid group name must be provided" : "Deve ser indicado um nome de grupo válido",
    "deleted {groupName}" : "{groupName} eliminado",
    "undo" : "anular",
    "never" : "nunca",
    "deleted {userName}" : "{userName} eliminado",
    "add group" : "adicionar grupo",
    "Invalid quota value \"{val}\"" : "Valor de quota inválido \"{val}\"",
    "enabled" : "ativado",
    "disabled" : "desativado",
    "User {uid} has been {state}!" : "Utilizador {uid} foi {state}!",
    "no group" : "sem grupo",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "A alteração da palavra-passe resultará na perda de dados, porque a recuperação de dados não está disponível para este utilizador",
    "Password successfully changed" : "Palavra-passe alterada com sucesso",
    "A valid username must be provided" : "Deve ser indicado um nome de utilizador válido",
    "Error creating user: {message}" : "Erro ao criar utilizador: {message}",
    "A valid password must be provided" : "Deve ser indicada uma palavra-passe válida",
    "A valid email must be provided" : "Deve ser fornecido um email válido",
    "Use the following link to confirm your changes to the email address: {link}" : "Use a seguinte hiperligação para confirmar as suas mudanças ao endereço de email: {link}",
    "Email address changed to {mailAddress} successfully." : "Endereço de email alterado com sucesso para {mailAddress}.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Olá,<br><br>apenas para informar que você tem uma conta %s.<br><br>O seu nome de utilizador: %s<br>Acesse à sua conta: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Parabéns!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Olá,\n\napenas para informar que você tem uma conta %s.\n\nO seu nome de utilizador: %s\nAcesse à sua conta: %s\n\n",
    "User documentation" : "Documentação do utilizador",
    "Administrator documentation" : "Documentação do administrador",
    "Online documentation" : "Documentação on-line",
    "Forum" : "Fórum",
    "Issue tracker" : "Monitorizador de problemas",
    "Commercial support" : "Apoio Comercial",
    "Apps Management" : "Gestão de Aplicações",
    "Developer documentation" : "Documentação do programador",
    "by %s" : "por %s",
    "%s-licensed" : "%s-autorizado",
    "Documentation:" : "Documentação:",
    "Admin documentation" : "Documentação do administrador",
    "Visit website" : "Visitar site da Web",
    "Report a bug" : "Comunicar um erro",
    "Show description …" : "Mostrar descrição...",
    "Hide description …" : "Ocultar descrição...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicação não tem uma versão mínima de ownCloud atribuída. Isto será um erro no ownCloud 11 e seguintes.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicação não tem uma versão máxima de ownCloud atribuída. Isto será um erro no ownCloud 11 e seguintes.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
    "Enable only for specific groups" : "Ativar apenas para grupos específicos",
    "Uninstall App" : "Desinstalar Aplicação",
    "Show enabled apps" : "Mostrar aplicações ativadas",
    "Show disabled apps" : "Mostrar aplicações desativadas",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Última execução de cron job: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Última execução de cron job: %s. Algo está errado.",
    "Cron was not executed yet!" : "Cron ainda não foi executado!",
    "Open documentation" : "Abrir documentação",
    "Execute one task with each page loaded" : "Executar uma tarefa com cada página carregada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registado num serviço webcron para chamar a página cron.php por http a cada 15 minutos.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usar o serviço sistema cron para ligar o ficheiro cron.php a cada 15 minutos.",
    "SSL Root Certificates" : "Certificados Root de SSL",
    "Common Name" : "Nome Comum",
    "Valid until" : "Válido até",
    "Issued By" : "Emitido Por",
    "Valid until %s" : "Válido até %s",
    "Import root certificate" : "Importar certificado root",
    "Server-side encryption" : "Encriptação do lado do servidor",
    "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
    "Please read carefully before activating server-side encryption: " : "Por favor, leia cuidadosamente antes de ativar a encriptação do lado do servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez ativada a encriptação, todos os ficheiros carregados para o servidor a partir deste ponto serão encriptados pelo servidor. Só será possível desativar a encriptação numa data mais tarde se o módulo de encriptação ativo suportar essa função, assim como todas as pré-condições (e.g. definir chave de recuperação) sejam cumpridas.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "A encriptação por si só não garante a segurança do sistema. Por favor, consulte a documentação ownCloud para mais informação acerca de como funciona a aplicação de encriptação, assim como os casos de uso suportados.",
    "Be aware that encryption always increases the file size." : "Tenha em conta que a encriptação aumenta sempre o tamanho do ficheiro.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
    "Enable encryption" : "Ative a encriptação",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova. Por favor, ative o \"Módulo de encriptação padrão\" e execute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova.",
    "Start migration" : "Iniciar migração",
    "Sharing" : "Partilha",
    "Allow apps to use the Share API" : "Permitir que os utilizadores usem a API de Partilha",
    "Allow users to share via link" : "Permitir que os utilizadores partilhem através do link",
    "Allow public uploads" : "Permitir envios públicos",
    "Enforce password protection" : "Forçar proteção por palavra-passe",
    "Set default expiration date" : "Definir a data de expiração predefinida",
    "Allow users to send mail notification for shared files" : "Permita que o utilizador envie notificações por correio electrónico para ficheiros partilhados",
    "Allow users to share file via social media" : "Permitir que os utilizadores partilhem o ficheiro através da rede social",
    "Expire after " : "Expira após",
    "days" : "dias",
    "Enforce expiration date" : "Forçar a data de expiração",
    "Allow resharing" : "Permitir 'voltar a partilhar'",
    "Allow sharing with groups" : "Permitir partilha com grupos",
    "Restrict users to only share with users in their groups" : "Restringe os utilizadores só a partilhar com utilizadores do seu grupo",
    "Allow users to send mail notification for shared files to other users" : "Autorizar utilizadores a enviarem notificações de email acerca de ficheiros partilhados a outros utilizadores",
    "Exclude groups from sharing" : "Excluir grupos das partilhas",
    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderão receber partilhas, mas não poderão iniciá-las.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Permitir o auto-completar de nome de utilizador no diálogo da partilha. Se isto for desativado, será necessário preencher o nome de utilizador completo.",
    "Restrict enumeration to group members" : "Restringir enumeração a membros do grupo",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tudo (problemas fatais, erros, avisos, informação, depuração)",
    "Info, warnings, errors and fatal issues" : "Informação, avisos, erros e problemas fatais",
    "Warnings, errors and fatal issues" : "Avisos, erros e problemas fatais",
    "Errors and fatal issues" : "Erros e problemas fatais",
    "Fatal issues only" : "Apenas problemas fatais",
    "Log" : "Registo",
    "What to log" : "O que registar",
    "Download logfile (%s)" : "Transferir ficheiro de registo (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "O ficheiro de registo é maior do que 100MB. A sua transferência poderá demorar algum tempo!",
    "None" : "Nenhum",
    "Login" : "Iniciar Sessão",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gestor de REDE NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "INICIAR TLS",
    "Email server" : "Servidor de E-mail",
    "This is used for sending out notifications." : "Isto é utilizado para enviar notificações",
    "Send mode" : "Modo de envio",
    "Encryption" : "Encriptação",
    "From address" : "Do endereço",
    "mail" : "correio",
    "Authentication method" : "Método de autenticação",
    "Authentication required" : "Autenticação necessária",
    "Server address" : "Endereço do servidor",
    "Port" : "Porta",
    "Credentials" : "Credenciais",
    "SMTP Username" : "Nome de utilizador SMTP",
    "SMTP Password" : "Palavra-passe SMTP",
    "Store credentials" : "Guardar credenciais",
    "Test email settings" : "Testar definições de e-mail",
    "Send email" : "Enviar e-mail",
    "Security & setup warnings" : "Avisos de configuração e segurança",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php não parece estar bem instalado para consultar variáveis de ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor, verifique a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação de instalação ↗</a> para notas de configuração do php e configuração php do seu servidor, especialmente quando utiliza php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "O PHP está aparentemente configurado para remover blocos doc em linha. Isto vai tornar inacessíveis várias aplicações básicas.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s abaixo da versão %2$s está instalado. Por motivos de estabilidade e desempenho, recomendamos que atualize para a nova versão %1$s.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "O Módulo PHP 'fileinfo' não se encontra instalado/activado. É fortemente recomendado que active este módulo para obter os melhores resultado com a detecção dos tipos de mime.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacionais está desativado, isto poderá levar a problemas com condições de corrida. Ative 'filelocking.enabled' no config.php para evitar estes problemas. Consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a> para mais informação.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacionais deverá ser configurado para usar bloqueio baseado em memória e não o bloqueio lento baseado em base de dados que vem predefenido. Consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a> para mais informação.",
    "System locale can not be set to a one which supports UTF-8." : "Não é possível definir a internacionalização do sistema para um que suporte o UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Isto significa que podem haver problemas com alguns caracteres nos nomes dos ficheiros.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nós recomendamos fortemente que instale no seu sistema os pacotes necessários para suportar uma das seguintes locallidades: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a sua instalação não está instalada na raiz do domínio e usa o sistema cron, pode haver problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwrite.cli.url\" no ficheiro config.php para o caminho webroot da sua instalação (Sugestão: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite é utilizado como uma base de dados. Para instalações maiores nós recomendamos que mude para uma interface de base de dados diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro tipo de base de dados, use a ferramenta de comando de linha: 'occ db:convert-type', ou veja a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Recomendamos utilizar o cron de sistema, visto que qualquer outro poderá afetar o desempenho e fiabilidade.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Não foi possível executar o cronjob via CLI. Os seguintes erros técnicos apareceram:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique os <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guias de instalação ↗</a>, e verifique se existe algum erro ou aviso no <a href=\"#log-section\">log</a>.",
    "All checks passed." : "Todas as verificações passaram.",
    "System Status" : "Estado do Sistema",
    "Tips & tricks" : "Dicas e truques",
    "How to do backups" : "Como fazer cópias de segurança",
    "Advanced monitoring" : "Monitorização avançada",
    "Performance tuning" : "Ajuste de desempenho",
    "Improving the config.php" : "Melhorar o config.php",
    "Theming" : "Temas",
    "Hardening and security guidance" : "Orientações de proteção e segurança",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente Desktop",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Se quer apoiar o projecto\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">junte-se ao desenvolvimento</a>\n\t\tou\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">espalhe a palavra</a>!",
    "Show First Run Wizard again" : "Mostrar novamente Wizard de Arranque Inicial",
    "Profile picture" : "Foto do perfil",
    "Upload new" : "Enviar novo",
    "Select from Files" : "Seleccione dos Ficheiros",
    "Remove image" : "Remover imagem",
    "png or jpg, max. 20 MB" : "png ou jpg, máx. 20 MB",
    "Picture provided by original account" : "Imagem fornecida pela conta original",
    "Cancel" : "Cancelar",
    "Choose as profile picture" : "Escolher como fotografia de perfil",
    "Full name" : "Nome completo",
    "No display name set" : "Nenhum nome display estabelecido",
    "Email" : "Email",
    "Your email address" : "O seu endereço de email",
    "Change email" : "Alterar email",
    "Set email" : "Definir email",
    "For password recovery and notifications" : "Para recuperação da palavra-passe e notificações",
    "No email address set" : "Nenhum endereço de email estabelecido",
    "You are member of the following groups:" : "Você é membro dos seguintes grupos:",
    "Password" : "Palavra-passe",
    "Unable to change your password" : "Não foi possível alterar a sua palavra-passe",
    "Current password" : "Palavra-passe atual",
    "New password" : "Nova palavra-passe",
    "Change password" : "Alterar palavra-passe",
    "Language" : "Idioma",
    "Help translate" : "Ajude a traduzir",
    "Unlimited" : "Ilimitado",
    "You are using %s of %s" : "Está a utilizar %s de %s",
    "You are using %s of %s (%s %%)" : "Está a utilizar %s de %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desenvolvido pela {communityopen}comunidade ownCloud{linkclose}, o {githubopen}código-fonte{linkclose} está licenciado sob a {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sessões",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estes são os clientes web, desktop e móveis actualmente ligados à sua ownCloud.",
    "Browser" : "Navegador",
    "Most recent activity" : "Atividade mais recente",
    "App passwords" : "Palavras-passe da Aplicação",
    "You've linked these apps." : "Ligou estas apps.",
    "Name" : "Nome",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Uma palavra-passe de app é um código de acesso que dá à app ou ao dispositivo permissão para aceder à sua conta %s.",
    "App name" : "Nome da app",
    "Create new app password" : "Criar nova palavra-passe de app",
    "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar a sua app ou dispositivo",
    "Username" : "Nome de utilizador",
    "Done" : "Concluído",
    "Version" : "Versão",
    "Personal" : "Pessoal",
    "Admin" : "Administração",
    "Error" : "Erro",
    "No panels for this section." : "Sem painéis para esta secção.",
    "Show enabled/disabled option" : "Mostrar opções ativada/desativadas",
    "Show storage location" : "Mostrar a localização do armazenamento",
    "Show last log in" : "Mostrar ultimo acesso de entrada",
    "Show user backend" : "Mostrar interface do utilizador",
    "Send email to new user" : "Enviar email ao novo utilizador",
    "Show email address" : "Mostrar endereço de email",
    "E-Mail" : "Correio Eletrónico",
    "Create" : "Criar",
    "Admin Recovery Password" : "Recuperação da Palavra-passe de Administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Digite a senha de recuperação, a fim de recuperar os ficheiros dos utilizadores durante a mudança da palavra-passe",
    "Add Group" : "Adicionar grupo",
    "Group" : "Grupo",
    "Everyone" : "Para todos",
    "Admins" : "Administrador",
    "Default Quota" : "Quota por padrão",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Insira a quota de armazenamento (ex: \"512 MB\" ou \"12 GB\")",
    "Other" : "Outro",
    "Full Name" : "Nome completo",
    "Group Admin for" : "Administrador de Grupo para",
    "Quota" : "Quota",
    "Storage Location" : "Localização do Armazenamento",
    "User Backend" : "Interface do Utilizador",
    "Last Login" : "Ultimo acesso",
    "change full name" : "alterar nome completo",
    "set new password" : "definir nova palavra-passe",
    "change email address" : "alterar endereço do correio eletrónico",
    "Default" : "Padrão",
    "Change" : "Alterar",
    "Share" : "Partilhar",
    "Domain" : "Domínio",
    "Add" : "Adicionar",
    "Email address" : "Endereço de correio eletrónico",
    "Invalid email address" : "Endereço de correio eletrónico inválido"
},
"nplurals=2; plural=(n != 1);");
